@@ -24,8 +24,7 @@ rrpc <- function(interface) { function(ws) {
   })
 }}
 
-rrpcServer <- function(interface, host='0.0.0.0',
-                       port=NULL, appDir=NULL, root="/") {
+rrpcServer <- function(interface, host='0.0.0.0', port=NULL, appDir=NULL, root="/") {
     app <- list(onWSOpen=rrpc(interface))
     if (!is.null(appDir)) {
         paths <- list()
@@ -71,7 +70,9 @@ sanitizeCommand <- function(command, callback) {
         'IsoplotR::evolution', 'IsoplotR::radialplot',
         'IsoplotR::agespectrum', 'IsoplotR::weightedmean',
         'IsoplotR::set.zeta', 'IsoplotR::helioplot', 'IsoplotR::age',
-        'IsoplotR::discfilter', 'IsoplotR::diseq', 'list', 'input','-'
+        'IsoplotR::discfilter', 'IsoplotR::diseq', 'list', 'input','-',':',
+        'rev','rainbow','topo.colors','terrain.colors','heat.colors',
+        'cm.colors'
     ))
     if (0 < length(failures)) {
         txt <- paste(failures, collapse=", ")
@@ -131,9 +132,9 @@ IsoplotR <- function(host='0.0.0.0', port=NULL) {
         }
         port <- s$getPort()
         utils::browseURL(paste0(protocol,
-          if (host == '0.0.0.0') '127.0.0.1' else host, ":", port))
-        extraMessage <-
-            "Call IsoplotRgui::stopIsoplotR() to stop serving IsoplotR\n"
+          if (host == '0.0.0.0') '127.0.0.1' else host,
+          ":", port))
+        extraMessage <- "Call IsoplotRgui::stopIsoplotR() to stop serving IsoplotR\n"
     }
     cat(sprintf("Listening on %s:%d\n%s", host, port, extraMessage))
     invisible(s)
@@ -169,8 +170,8 @@ stopIsoplotR <- function(server=NULL) {
 #' to show the GUI.
 #' @return This function does not return.
 #' @examples
-#' # runs indefinitely unless interrupted by the user:
-#' \dontrun{daemon(3838)}
+#' # this function runs indefinitely unless interrupted by the user.
+#' \donttest{daemon(3839)}
 #' @export
 daemon <- function(port=NULL, host='127.0.0.1') {
     IsoplotR(host=host, port=port)
